@@ -1,19 +1,11 @@
-﻿#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
-# Copyright 2020-2021 John Mille <john@compose-x.io>
+# Copyright 2020-2022 John Mille <john@compose-x.io>
 
 """
 AppMesh related conditions
 """
 
-from troposphere import (
-    Ref,
-    Equals,
-    If,
-    AWS_ACCOUNT_ID,
-    GetAtt,
-    AWS_STACK_NAME,
-)
+from troposphere import AWS_ACCOUNT_ID, AWS_STACK_NAME, Equals, GetAtt, If, Ref
 from troposphere.appmesh import Mesh
 
 from ecs_composex.appmesh.appmesh_params import MESH_NAME, MESH_OWNER_ID
