@@ -1,6 +1,5 @@
-﻿#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
-# Copyright 2020-2021 John Mille <john@compose-x.io>
+# Copyright 2020-2022 John Mille <john@compose-x.io>
 
 """
 Main module for AppMesh.
@@ -25,7 +24,7 @@ from ecs_composex.ecs import ecs_params
 from ecs_composex.resources_import import import_record_properties
 
 
-class Mesh(object):
+class Mesh:
     """
     Class for AppMesh mesh
     """
@@ -36,7 +35,7 @@ class Mesh(object):
     services_key = appmesh_params.SERVICES_KEY
     required_keys = [nodes_key, routers_key, services_key]
 
-    def __init__(self, mesh_definition, services_root_stack, settings, dns_settings):
+    def __init__(self, mesh_definition, services_root_stack, settings):
         """
         Method to initialize the Mesh
 
@@ -104,7 +103,7 @@ class Mesh(object):
                 raise KeyError(f"Key {key} is missing. Required {self.required_keys}")
         self.define_nodes(settings, services_root_stack, self.appmesh)
         self.define_routes_and_routers()
-        self.define_virtual_services(dns_settings)
+        self.define_virtual_services(settings)
 
     def define_nodes(self, settings, services_root_stack, mesh):
         """
@@ -173,7 +172,7 @@ class Mesh(object):
                 self.nodes,
             )
 
-    def define_virtual_services(self, dns_settings):
+    def define_virtual_services(self, settings):
         """
         Method to parse the services and map them to nodes and routers.
         """
@@ -185,10 +184,10 @@ class Mesh(object):
                 self.routers,
                 self.nodes,
                 self.appmesh,
-                dns_settings,
+                settings,
             )
 
-    def render_mesh_template(self, services_stack, settings, dns_settings):
+    def render_mesh_template(self, services_stack, settings):
         """
         Method to create the AppMesh template stack.
 
@@ -200,9 +199,9 @@ class Mesh(object):
         ):
             services_stack.stack_template.add_resource(self.appmesh)
             add_appmesh_conditions(services_stack.stack_template)
-        self.process_mesh_components(services_stack, dns_settings)
+        self.process_mesh_components(services_stack, settings)
 
-    def process_mesh_components(self, services_stack, dns_settings):
+    def process_mesh_components(self, services_stack, settings):
 
         for router_name in self.routers:
             router = self.routers[router_name]
@@ -212,7 +211,7 @@ class Mesh(object):
         for service_name in self.services:
             service = self.services[service_name]
             services_stack.stack_template.add_resource(service.service)
-            service.add_dns_entries(services_stack.stack_template, dns_settings)
+            service.add_dns_entries(services_stack.stack_template, settings)
         for res_name in services_stack.stack_template.resources:
             res = services_stack.stack_template.resources[res_name]
             if issubclass(type(res), ComposeXStack) and isinstance(self.appmesh, Mesh):
