@@ -1,6 +1,5 @@
-#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
-# Copyright 2020-2021 John Mille <john@compose-x.io>
+# Copyright 2020-2022 John Mille <john@compose-x.io>
 
 """
 Console script for ecs_composex.
@@ -14,7 +13,8 @@ from ecs_composex.common import LOG
 from ecs_composex.common.aws import deploy, plan
 from ecs_composex.common.settings import ComposeXSettings
 from ecs_composex.common.stacks import process_stacks
-from ecs_composex.ecs_composex import evaluate_ecr_configs, generate_full_template
+from ecs_composex.ecr.docker_opts import evaluate_docker_configs, evaluate_ecr_configs
+from ecs_composex.ecs_composex import generate_full_template
 
 
 class ArgparseHelper(argparse._HelpAction):
@@ -78,8 +78,9 @@ def main_parser():
     )
     base_command_parser.add_argument(
         "-n",
+        "-p",
         "--name",
-        help="Name of your stack",
+        help="Name of your stack / docker project",
         required=True,
         type=str,
         dest=ComposeXSettings.name_arg,
@@ -100,9 +101,9 @@ def main_parser():
         "default use default region from config or environment vars",
     )
     base_command_parser.add_argument(
-        "--az",
+        "--azs",
         dest=ComposeXSettings.zones_arg,
-        default=ComposeXSettings.default_azs,
+        default=[],
         action="append",
         required=False,
         help="List AZs you want to deploy to specifically within the region",
@@ -157,7 +158,6 @@ def main():
     LOG.debug(args)
     settings = ComposeXSettings(**vars(args))
     settings.set_bucket_name_from_account_id()
-    settings.set_azs_from_api()
     LOG.debug(settings)
 
     if settings.deploy and not settings.upload:
@@ -165,6 +165,7 @@ def main():
             "You must update the templates in order to deploy. We won't be deploying."
         )
         settings.deploy = False
+    evaluate_docker_configs(settings)
     scan_results = evaluate_ecr_configs(settings)
     if scan_results and not settings.ignore_ecr_findings:
         warnings.warn("SCAN Images failed for instructed images. Failure")
