@@ -1,10 +1,17 @@
-﻿#   -*- coding: utf-8 -*-
 #  SPDX-License-Identifier: MPL-2.0
-#  Copyright 2020-2021 John Mille <john@compose-x.io>
+#  Copyright 2020-2022 John Mille <john@compose-x.io>
 
 """
 Module to manage the creation of Dashboards
 """
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, List, Union
+
+if TYPE_CHECKING:
+    from ecs_composex.common.settings import ComposeXSettings
+    from ecs_composex.mods_manager import XResourceModule
+    from ecs_composex.ecs.ecs_family import ComposeFamily
 
 import json
 
@@ -21,17 +28,15 @@ from ecs_composex.common import (
 )
 from ecs_composex.common.cfn_conditions import define_stack_name
 from ecs_composex.common.stacks import ComposeXStack
-from ecs_composex.dashboards.dashboards_params import RES_KEY
 from ecs_composex.dashboards.dashboards_services_metrics import ServiceEcsWidget
 from ecs_composex.ecs.ecs_params import CLUSTER_NAME, SERVICE_T
 
 
-def get_family_from_name(settings, name):
+def get_family_from_name(settings: ComposeXSettings, name: str) -> ComposeFamily | None:
     """
 
     :param ecs_composex.common.settings.ComposeXSettings settings:
     :param name:
-    :return:
     """
     for family in settings.families.values():
         if family.name == name:
@@ -39,7 +44,9 @@ def get_family_from_name(settings, name):
     return None
 
 
-def retrieve_services(settings, services, x_stack):
+def retrieve_services(
+    settings: ComposeXSettings, services: dict, x_stack: ComposeXStack
+) -> list[tuple]:
     """
     Function to
 
@@ -74,16 +81,19 @@ def retrieve_services(settings, services, x_stack):
     return services_params
 
 
-def create_dashboards(settings, x_stack):
+def create_dashboards(
+    settings: ComposeXSettings, x_stack: ComposeXStack, module: XResourceModule
+) -> None:
     """
     Loop to iterate over dashboards definitions
 
     :param ecs_composex.common.settings.ComposeXSettings settings:
     :param ecs_composex.common.stacks.ComposeXStack x_stack:
+    :param ModManager module:
     """
-    if not keyisset(RES_KEY, settings.compose_content):
-        LOG.error(f"No {RES_KEY} defined")
-    dashboards = settings.compose_content[RES_KEY]
+    if not keyisset(module.res_key, settings.compose_content):
+        LOG.error(f"No {module.res_key} defined")
+    dashboards = settings.compose_content[module.res_key]
     for name, dashboard in dashboards.items():
         widgets = []
         if keyisset("Services", dashboard):
@@ -113,10 +123,12 @@ class XStack(ComposeXStack):
     Class to manage the Dashboard stack
     """
 
-    def __init__(self, title, settings, **kwargs):
+    def __init__(
+        self, title, settings: ComposeXSettings, module: XResourceModule, **kwargs
+    ):
         params = {
             CLUSTER_NAME.title: settings.ecs_cluster,
         }
         stack_template = build_template("Root template for Dashboards", [CLUSTER_NAME])
         super().__init__(title, stack_template, stack_parameters=params, **kwargs)
-        create_dashboards(settings, self)
+        create_dashboards(settings, self, module)
