@@ -1,6 +1,5 @@
-#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
-# Copyright 2020-2021 John Mille <john@compose-x.io>
+# Copyright 2020-2022 John Mille <john@compose-x.io>
 
 """
 Parameters bound to  ecs_composex.ecs
@@ -14,13 +13,12 @@ You can change the names *values* so you like so long as you keep it [a-zA-Z0-9]
 from troposphere import ImportValue, Ref, Select, Split, Sub
 
 from ecs_composex.common.cfn_params import ROOT_STACK_NAME_T, Parameter
-from ecs_composex.common.ecs_composex import CFN_EXPORT_DELIMITER as delim
-from ecs_composex.vpc.vpc_params import SG_ID_TYPE
+from ecs_composex.common.ecs_composex import CFN_EXPORT_DELIMITER as DELIM
+from ecs_composex.vpc.vpc_params import SG_ID_TYPE, SUBNETS_TYPE
 
 CLUSTER_T = "EcsCluster"
 LOG_GROUP_T = "ServicesLogGroup"
 SG_T = "ServiceSecurityGroup"
-NETWORK_MODE = "awsvpc"
 EXEC_ROLE_T = "EcsExecutionRole"
 TASK_ROLE_T = "EcsTaskRole"
 SERVICE_T = "EcsServiceDefinition"
@@ -29,13 +27,20 @@ RES_KEY = "services"
 ECS_TASK_FAMILY_LABEL = "ecs.task.family"
 SERVICE_SCALING_TARGET = "ServiceScalingTarget"
 
+ECS_COMPUTE_SETTINGS = "ECS Compute Settings"
+LOGGING_SETTINGS = "Logging Settings"
+FARGATE_SETTINGS = "AWS Fargate Settings"
+
 LAUNCH_TYPE_T = "EcsLaunchType"
 LAUNCH_TYPE = Parameter(
     LAUNCH_TYPE_T,
+    group_label=ECS_COMPUTE_SETTINGS,
+    label="Defines the Launch Type to use for ECS Service",
     Type="String",
     AllowedValues=[
         "EC2",
         "FARGATE",
+        "EXTERNAL",
         "FARGATE_PROVIDERS",
         "CLUSTER_MODE",
         "SERVICE_MODE",
@@ -46,13 +51,13 @@ LAUNCH_TYPE = Parameter(
 FARGATE_VERSION_T = "FargatePlatformVersion"
 FARGATE_VERSION = Parameter(
     FARGATE_VERSION_T,
+    group_label=ECS_COMPUTE_SETTINGS,
+    label="Fargate platform version",
     Type="String",
     AllowedValues=["DEFAULT", "1.4.0", "1.3.0"],
     Default="1.4.0",
 )
 
-IS_PUBLIC_T = "ExposeServicePublicly"
-IS_PUBLIC = Parameter(IS_PUBLIC_T, AllowedValues=["True", "False"], Type="String")
 
 CLUSTER_NAME_T = "EcsCluster"
 CLUSTER_NAME = Parameter(
@@ -62,14 +67,6 @@ CLUSTER_NAME = Parameter(
     Default="default",
 )
 
-CREATE_CLUSTER_PT = "CreateEcsCluster"
-CREATE_CLUSTER = Parameter(
-    CREATE_CLUSTER_PT,
-    Type="String",
-    AllowedValues=["True", "False"],
-    Default="True",
-)
-
 SERVICE_NAME_T = "MicroServiceName"
 SERVICE_NAME = Parameter(SERVICE_NAME_T, Type="String", AllowedPattern=r"[a-zA-Z0-9-]+")
 
@@ -81,11 +78,15 @@ SERVICE_HOSTNAME = Parameter(
     AllowedPattern=r"^[a-z0-9-.]+$",
 )
 
-SERVICE_IMAGE_T = "MicroserviceImage"
-SERVICE_IMAGE = Parameter(SERVICE_IMAGE_T, Type="String")
-
 SERVICE_COUNT_T = "MicroservicesCount"
-SERVICE_COUNT = Parameter(SERVICE_COUNT_T, Type="Number", MinValue=0, Default=0)
+SERVICE_COUNT = Parameter(
+    SERVICE_COUNT_T,
+    group_label=ECS_COMPUTE_SETTINGS,
+    Description="Defines how many containers by default the service should have",
+    Type="Number",
+    MinValue=0,
+    Default=0,
+)
 
 ELB_GRACE_PERIOD_T = "ElbGracePeriod"
 ELB_GRACE_PERIOD = Parameter(
@@ -96,17 +97,12 @@ ELB_GRACE_PERIOD = Parameter(
     MaxValue=2147483647,
 )
 
-ECS_CONTROLLER_T = "EcsServiceDeploymentController"
-ECS_CONTROLLER = Parameter(
-    ECS_CONTROLLER_T,
-    Type="String",
-    AllowedValues=["ECS", "CODE_DEPLOY", "EXTERNAL"],
-    Default="ECS",
-)
-
 CREATE_LOG_GROUP_T = "CreateLogGroup"
 CREATE_LOG_GROUP = Parameter(
     CREATE_LOG_GROUP_T,
+    group_label=LOGGING_SETTINGS,
+    label="How long to retain logs? (in days)",
+    Description="Amount of time to retain logs, in days",
     Type="String",
     AllowedValues=["True", "False"],
     Default="True",
@@ -116,6 +112,8 @@ LOG_GROUP_NAME = Parameter(LOG_GROUP_NAME_T, Type="String", Default="ComposeXDef
 LOG_GROUP_RETENTION_T = "ServiceLogGroupRetentionPeriod"
 LOG_GROUP_RETENTION = Parameter(
     LOG_GROUP_RETENTION_T,
+    group_label=LOGGING_SETTINGS,
+    label="Name of the CW Log Group to store the containers logs into",
     Type="Number",
     Default=30,
     AllowedValues=[
@@ -139,12 +137,27 @@ LOG_GROUP_RETENTION = Parameter(
     ],
 )
 
+RUNTIME_CPU_ARCHITECTURE_T = "RuntimeCpuArchitecture"
+RUNTIME_CPU_ARCHITECTURE = Parameter(
+    RUNTIME_CPU_ARCHITECTURE_T,
+    group_label=ECS_COMPUTE_SETTINGS,
+    label="Choose CPU Architecture to use for your services",
+    Type="String",
+    AllowedValues=["X86_64", "ARM64"],
+    Default="X86_64",
+)
+
+
+RUNTIME_OS_FAMILY_T = "RuntimeOperatingSystemFamily"
+RUNTIME_OS_FAMILY = Parameter(RUNTIME_OS_FAMILY_T, Type="String", Default="LINUX")
+
+
 FARGATE_MODES = {
-    256: [2 ** i for i in [9, 10, 11]],
-    512: [(2 ** 10) * i for i in range(1, 5)],
-    1024: [(2 ** 10) * i for i in range(2, 9)],
-    2048: [(2 ** 10) * i for i in range(4, 17)],
-    4096: [(2 ** 10) * i for i in range(8, 33)],
+    256: [2**i for i in [9, 10, 11]],
+    512: [(2**10) * i for i in range(1, 5)],
+    1024: [(2**10) * i for i in range(2, 9)],
+    2048: [(2**10) * i for i in range(4, 17)],
+    4096: [(2**10) * i for i in range(8, 33)],
 }
 
 FARGATE_MODES_VALUES = []
@@ -155,6 +168,8 @@ for cpu in FARGATE_MODES.keys():
 FARGATE_CPU_RAM_CONFIG_T = "FargateCpuRamConfiguration"
 FARGATE_CPU_RAM_CONFIG = Parameter(
     FARGATE_CPU_RAM_CONFIG_T,
+    group_label=FARGATE_SETTINGS,
+    Description="AWS Fargate CPU/RAM combination for your ECS Task",
     Type="String",
     AllowedValues=FARGATE_MODES_VALUES,
     Default="256!512",
@@ -179,12 +194,29 @@ XRAY_IMAGE_T = "AWSXRayImage"
 XRAY_IMAGE = Parameter(XRAY_IMAGE_T, Type="String", Default=AWS_XRAY_IMAGE)
 
 
+NETWORK_MODE_T = "TaskNetworkingMode"
+NETWORK_MODE = Parameter(
+    NETWORK_MODE_T,
+    Type="String",
+    AllowedValues=["awsvpc", "bridge", "host", "none"],
+    Default="awsvpc",
+)
+
+IPC_MODE_T = "TaskIpcMode"
+IPC_MODE = Parameter(
+    IPC_MODE_T, Type="String", AllowedValues=["task", "host", "none"], Default="none"
+)
+
+SERVICE_SUBNETS_T = "ECSServiceSubnets"
+SERVICE_SUBNETS = Parameter(SERVICE_SUBNETS_T, Type=SUBNETS_TYPE)
+
+
 def get_import_service_group_id(remote_service_name):
     """
     Function to return the ImportValue(Sub()) for given ecs_service name
     """
     return ImportValue(
         Sub(
-            f"${{{ROOT_STACK_NAME_T}}}{delim}{remote_service_name}{delim}{SERVICE_GROUP_ID_T}"
+            f"${{{ROOT_STACK_NAME_T}}}{DELIM}{remote_service_name}{DELIM}{SERVICE_GROUP_ID_T}"
         )
     )
