@@ -1,18 +1,15 @@
-﻿#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
-# Copyright 2020-2021 John Mille <john@compose-x.io>
+# Copyright 2020-2022 John Mille <john@compose-x.io>
 
 import re
 from os import path
 
-from ecs_composex.common import NONALPHANUM
 from ecs_composex.common.cfn_params import Parameter
 from ecs_composex.common.ecs_composex import X_KEY
 from ecs_composex.vpc.vpc_params import SG_ID_TYPE
 
 MOD_KEY = path.basename(path.dirname(path.abspath(__file__)))
 RES_KEY = f"{X_KEY}{MOD_KEY}"
-MAPPINGS_KEY = NONALPHANUM.sub("", MOD_KEY)
 
 
 FS_REGEXP = re.compile(
@@ -29,7 +26,7 @@ FS_ID = Parameter(
 
 FS_PORT_T = "FilesystemPort"
 FS_PORT = Parameter(
-    FS_PORT_T, Type="Number", MinValue=1, MaxValue=((2 ** 16) - 1), Default=2049
+    FS_PORT_T, Type="Number", MinValue=1, MaxValue=((2**16) - 1), Default=2049
 )
 
 FS_ARN_T = "FilesystemArn"
