@@ -1,14 +1,21 @@
-#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
-# Copyright 2020-2021 John Mille <john@compose-x.io>
+# Copyright 2020-2022 John Mille <john@compose-x.io>
 
 """
 Module to handle Linking ECS tasks and the elastic cache clusters
 """
 
-from compose_x_common.compose_x_common import keyisset
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, List
+
+if TYPE_CHECKING:
+    from ecs_composex.common.settings import ComposeXSettings
+    from .elasticache_stack import CacheCluster
+
 from troposphere import FindInMap, Select
 
+from ecs_composex.common import LOG
 from ecs_composex.elasticache.elasticache_aws import lookup_cluster_resource
 from ecs_composex.elasticache.elasticache_params import (
     CLUSTER_SG,
@@ -21,7 +28,9 @@ from ecs_composex.rds_resources_settings import (
 )
 
 
-def link_cluster_to_service(cluster, cluster_mappings, mapping_name):
+def link_cluster_to_service(
+    cluster: CacheCluster, cluster_mappings: dict, mapping_name: str
+):
     """
     Function to go over each service defined in the DB and assign found DB settings to service
 
@@ -43,7 +52,9 @@ def link_cluster_to_service(cluster, cluster_mappings, mapping_name):
         )
 
 
-def create_lookup_mappings(mappings, lookup_resources, settings):
+def create_lookup_mappings(
+    mappings: dict, lookup_resources: list[CacheCluster], settings: ComposeXSettings
+):
     """
     Function to build up the Mappings for ElastiCache
 
@@ -64,28 +75,20 @@ def elasticache_to_ecs(resources, services_stack, res_root_stack, settings):
     """
     Entrypoint function to map new and lookup resources to ECS Services
 
-    :param list resources:
+    :param dict resources:
     :param ecs_composex.common.stacks.ComposeXStack services_stack:
     :param ecs_composex.common.stacks.ComposeXStack res_root_stack:
     :param ecs_composex.common.settings.ComposeXSettings settings:
     """
-    new_resources = [
-        resources[res_name]
-        for res_name in resources
-        if resources[res_name].cfn_resource
-    ]
-    lookup_resources = [
-        resources[res_name] for res_name in resources if resources[res_name].mappings
-    ]
-    for new_res in new_resources:
-        handle_new_tcp_resource(
-            new_res,
-            res_root_stack,
-            port_parameter=new_res.port_attr,
-            sg_parameter=CLUSTER_SG,
-        )
-    for lookup_res in lookup_resources:
-        if keyisset(lookup_res.logical_name, settings.mappings[RES_KEY]):
+    for resource_name, resource in resources.items():
+        LOG.info(f"{resource.module.res_key}.{resource_name} - Linking to services")
+        if not resource.mappings and resource.cfn_resource:
+            handle_new_tcp_resource(
+                resource,
+                port_parameter=resource.port_attr,
+                sg_parameter=CLUSTER_SG,
+            )
+        elif resource.mappings and not resource.cfn_resource:
             link_cluster_to_service(
-                lookup_res, settings.mappings[RES_KEY], mapping_name=MAPPINGS_KEY
+                resource, settings.mappings[RES_KEY], mapping_name=MAPPINGS_KEY
             )
