@@ -1,6 +1,5 @@
-﻿#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
-# Copyright 2020-2021 John Mille <john@compose-x.io>
+# Copyright 2020-2022 John Mille <john@compose-x.io>
 
 
 from compose_x_common.compose_x_common import keyisset
@@ -23,19 +22,20 @@ from troposphere.events import (
 )
 from troposphere.iam import Policy, PolicyType, Role
 
-from ecs_composex.common import LOG, add_parameters
+from ecs_composex.common import add_parameters, setup_logging
 from ecs_composex.common.cfn_params import Parameter
 from ecs_composex.ecs.ecs_params import (
     CLUSTER_NAME,
-    EXEC_ROLE_T,
     FARGATE_VERSION,
     SERVICE_SCALING_TARGET,
+    SERVICE_SUBNETS,
     SERVICE_T,
-    TASK_ROLE_T,
     TASK_T,
 )
 from ecs_composex.vpc.vpc_params import APP_SUBNETS, SG_ID_TYPE, SUBNETS_TYPE
 
+LOG = setup_logging()
+
 
 def delete_service_from_template(service):
     """
@@ -54,11 +54,10 @@ def delete_service_from_template(service):
             del service[0].template.outputs[output_name]
 
 
-def define_service_targets(settings, stack, rule, cluster_arn):
+def define_service_targets(stack, rule, cluster_arn):
     """
     Function to define the targets for service.
 
-    :param ecs_composex.common.settings.ComposeXSettings settings:
     :param ecs_composex.events.events_stack.XStack stack:
     :param ecs_composex.events.events_stack.Rule rule:
     :param troposphere.Sub cluster_arn:
@@ -123,40 +122,45 @@ def define_service_targets(settings, stack, rule, cluster_arn):
         events_policy = Policy(
             PolicyName="EventsAccess", PolicyDocument=events_policy_doc
         )
-        service[0].template.add_resource(
-            PolicyType(
-                "EventsAccessPolicy",
-                PolicyName="EventsAccess",
-                PolicyDocument=task_events_policy_doc,
-                Roles=[
-                    Ref(service[0].template.resources[TASK_ROLE_T]),
-                    Ref(service[0].template.resources[EXEC_ROLE_T]),
-                ],
-            )
-        )
-        role = stack.stack_template.add_resource(
-            Role(
-                f"{rule.logical_name}IamRoleToTrigger{service[0].logical_name}",
-                AssumeRolePolicyDocument={
-                    "Version": "2012-10-17",
-                    "Statement": [
-                        {
-                            "Sid": "TrustPolicy",
-                            "Effect": "Allow",
-                            "Principal": {
-                                "Service": Sub(f"events.${{{AWS_URL_SUFFIX}}}")
-                            },
-                            "Action": "sts:AssumeRole",
-                        }
+        if "EventsAccessPolicy" not in service[0].template.resources:
+            service[0].template.add_resource(
+                PolicyType(
+                    "EventsAccessPolicy",
+                    PolicyName="EventsAccess",
+                    PolicyDocument=task_events_policy_doc,
+                    Roles=[
+                        service[0].iam_manager.task_role.name,
+                        service[0].iam_manager.exec_role.name,
                     ],
-                },
-                ManagedPolicyArns=[],
-                Policies=[events_policy],
-                PermissionsBoundary=Ref(AWS_NO_VALUE),
+                )
             )
-        )
-        if service[0].iam and keyisset("PermissionsBoundary", service[0].iam):
-            role.PermissionsBoundary = service[0].iam["PermissionsBoundary"]
+        role_name = f"{rule.logical_name}IamRoleToTrigger{service[0].logical_name}"
+        if role_name not in stack.stack_template.resources:
+            role = stack.stack_template.add_resource(
+                Role(
+                    f"{rule.logical_name}IamRoleToTrigger{service[0].logical_name}",
+                    AssumeRolePolicyDocument={
+                        "Version": "2012-10-17",
+                        "Statement": [
+                            {
+                                "Sid": "TrustPolicy",
+                                "Effect": "Allow",
+                                "Principal": {
+                                    "Service": Sub(f"events.${{{AWS_URL_SUFFIX}}}")
+                                },
+                                "Action": "sts:AssumeRole",
+                            }
+                        ],
+                    },
+                    ManagedPolicyArns=[],
+                    Policies=[events_policy],
+                    PermissionsBoundary=Ref(AWS_NO_VALUE),
+                )
+            )
+            if service[0].iam_manager.permissions_boundary:
+                role.PermissionsBoundary = service[0].iam_manager.permissions_boundary
+        else:
+            role = stack.stack_template.resources[role_name]
         add_parameters(
             stack.stack_template,
             [service_sg_param, service_task_def_param, service_subnets_param],
@@ -169,11 +173,11 @@ def define_service_targets(settings, stack, rule, cluster_arn):
                 ),
                 service_task_def_param.title: GetAtt(
                     service[0].logical_name,
-                    f"Outputs.{service[0].logical_name}{TASK_T}",
+                    f"Outputs.{service[0].task_definition.title}",
                 ),
                 service_subnets_param.title: GetAtt(
                     service[0].logical_name,
-                    f"Outputs.{service[0].logical_name}{APP_SUBNETS.title}",
+                    f"Outputs.{SERVICE_SUBNETS.title}",
                 ),
             }
         )
@@ -183,6 +187,7 @@ def define_service_targets(settings, stack, rule, cluster_arn):
                     AwsVpcConfiguration=AwsVpcConfiguration(
                         Subnets=Ref(service_subnets_param),
                         SecurityGroups=[Ref(service_sg_param)],
+                        AssignPublicIp=service[0].service_networking.eip_assign,
                     )
                 ),
                 PlatformVersion=Ref(FARGATE_VERSION),
@@ -232,4 +237,4 @@ def events_to_ecs(resources, services_stack, res_root_stack, settings):
     ]
     for rule in rules:
         if rule.families_targets:
-            define_service_targets(settings, res_root_stack, rule, cluster_arn)
+            define_service_targets(res_root_stack, rule, cluster_arn)
