@@ -1,6 +1,5 @@
-﻿#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
-# Copyright 2020-2021 John Mille <john@compose-x.io>
+# Copyright 2020-2022 John Mille <john@compose-x.io>
 
 import re
 from os import path
@@ -25,6 +24,6 @@ KMS_KEY_ID_T = "KmsKeyId"
 KMS_KEY_ALIAS_NAME_T = "KmsKeyAliasName"
 KMS_KEY_ALIAS_ARN_T = "KmsKeyAliasArn"
 
-KMS_KEY_ID = Parameter(KMS_KEY_ID_T, Type="String")
+KMS_KEY_ID = Parameter(KMS_KEY_ID_T, return_value="KeyId", Type="String")
 KMS_KEY_ARN = Parameter(KMS_KEY_ARN_T, return_value="Arn", Type="String")
 KMS_KEY_ALIAS_NAME = Parameter(KMS_KEY_ALIAS_NAME_T, Type="String")
