@@ -1,6 +1,17 @@
-#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
-# Copyright 2020-2021 John Mille <john@compose-x.io>
+# Copyright 2020-2022 John Mille <john@compose-x.io>
+
+"""
+Manage Creation/Deletion of AWS KMS Keys
+"""
+
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Union
+
+if TYPE_CHECKING:
+    from ecs_composex.common.settings import ComposeXSettings
+    from ecs_composex.mods_manager import XResourceModule
 
 from botocore.exceptions import ClientError
 from compose_x_common.aws.kms import KMS_KEY_ARN_RE
@@ -10,51 +21,48 @@ from troposphere.kms import Alias, Key
 
 from ecs_composex.common import LOG, build_template
 from ecs_composex.common.cfn_conditions import define_stack_name
-from ecs_composex.common.compose_resources import (
-    XResource,
+from ecs_composex.common.stacks import ComposeXStack
+from ecs_composex.compose.x_resources.api_x_resources import ApiXResource
+from ecs_composex.compose.x_resources.environment_x_resources import (
+    AwsEnvironmentResource,
+)
+from ecs_composex.compose.x_resources.helpers import (
     set_lookup_resources,
     set_new_resources,
     set_resources,
-    set_use_resources,
 )
-from ecs_composex.common.stacks import ComposeXStack
-from ecs_composex.iam.import_sam_policies import get_access_types
 from ecs_composex.kms import metadata
-from ecs_composex.kms.kms_params import (
-    KMS_KEY_ALIAS_NAME,
-    KMS_KEY_ARN,
-    KMS_KEY_ID,
-    MAPPINGS_KEY,
-    MOD_KEY,
-    RES_KEY,
-)
+from ecs_composex.kms.kms_ecs_cluster import handle_ecs_cluster
+from ecs_composex.kms.kms_params import KMS_KEY_ALIAS_NAME, KMS_KEY_ARN, KMS_KEY_ID
+from ecs_composex.kms.kms_s3 import handle_bucket_kms
+from ecs_composex.kms.kms_sqs import handle_queue_kms
 from ecs_composex.kms.kms_template import create_kms_template
 from ecs_composex.resources_import import import_record_properties
+from ecs_composex.s3.s3_bucket import Bucket
+from ecs_composex.sqs.sqs_stack import Queue
 
 
-def get_key_config(key, account_id, resource_id):
+def get_key_config(key, account_id: str, resource_id: str) -> dict | None:
     """
 
     :param Key key:
+    :param str account_id: unused
+    :param str resource_id: unused
     :return:
     """
     key_attributes_mappings = {
-        KMS_KEY_ARN.return_value: "KeyMetadata::Arn",
-        KMS_KEY_ID.title: "KeyMetadata::KeyId",
+        KMS_KEY_ARN: "KeyMetadata::Arn",
+        KMS_KEY_ID: "KeyMetadata::KeyId",
     }
     client = key.lookup_session.client("kms")
     try:
         key_desc = client.describe_key(KeyId=key.arn)
         key_attributes = attributes_to_mapping(key_desc, key_attributes_mappings)
         try:
-            aliases_r = client.list_aliases(KeyId=key_attributes[KMS_KEY_ID.title])
-            key_attributes[KMS_KEY_ALIAS_NAME.title] = aliases_r["Aliases"][0][
-                "AliasName"
-            ]
+            aliases_r = client.list_aliases(KeyId=key_attributes[KMS_KEY_ID])
+            key_attributes[KMS_KEY_ALIAS_NAME] = aliases_r["Aliases"][0]["AliasName"]
         except client.exceptions.NotFoundException:
-            LOG.debug(
-                f"No alias was found for KMS Key {key_attributes[KMS_KEY_ID.title]}"
-            )
+            LOG.debug(f"{key.module.res_key}.{key.name} - No KMS Key Alias.")
         return key_attributes
     except client.exceptions.QueueDoesNotExist:
         return None
@@ -63,7 +71,7 @@ def get_key_config(key, account_id, resource_id):
         raise
 
 
-def define_default_key_policy():
+def define_default_key_policy() -> dict:
     """
     Function to return the default KMS management policy allowing root account access.
     :return: policy
@@ -92,16 +100,30 @@ def define_default_key_policy():
     return policy
 
 
-class KmsKey(XResource):
+class KmsKey(AwsEnvironmentResource, ApiXResource):
     """
     Class to represent a KMS Key
     """
 
-    policies_scaffolds = get_access_types(MOD_KEY)
+    def __init__(
+        self,
+        name: str,
+        definition: dict,
+        module: XResourceModule,
+        settings: ComposeXSettings,
+    ):
+        super().__init__(name, definition, module, settings)
+        self.arn_parameter = KMS_KEY_ARN
+        self.ref_parameter = KMS_KEY_ID
 
     def init_outputs(self):
         self.output_properties = {
-            KMS_KEY_ID: (self.logical_name, self.cfn_resource, Ref, None),
+            KMS_KEY_ID: (
+                f"{self.logical_name}{KMS_KEY_ID.title}",
+                self.cfn_resource,
+                Ref,
+                None,
+            ),
             KMS_KEY_ARN: (
                 f"{self.logical_name}{KMS_KEY_ARN.return_value}",
                 self.cfn_resource,
@@ -139,8 +161,8 @@ class KmsKey(XResource):
 
         :param troposphere.Template template:
         """
-        if self.settings and keyisset("Alias", self.settings):
-            alias_name = self.settings["Alias"]
+        if self.parameters and keyisset("Alias", self.parameters):
+            alias_name = self.parameters["Alias"]
             if not (alias_name.startswith("alias/") or alias_name.startswith("aws")):
                 alias_name = Sub(
                     f"alias/${{STACK_NAME}}/{alias_name}",
@@ -156,30 +178,63 @@ class KmsKey(XResource):
                 Metadata=metadata,
             )
 
+    def handle_x_dependencies(self, settings, root_stack=None) -> None:
+        """
+        WIll go over all the new resources to create in the execution and search for properties that can be updated
+        with itself
+
+        :param ecs_composex.common.settings.ComposeXSettings settings:
+        :param ComposeXStack root_stack: Not used. Present for general compatibility
+        """
+        handle_ecs_cluster(settings, self)
+        for resource in settings.get_x_resources(include_mappings=False):
+            if not resource.cfn_resource:
+                continue
+            if not resource.stack:
+                LOG.debug(
+                    f"resource {resource.name} has no `stack` attribute defined. Skipping"
+                )
+                continue
+            mappings = [(Bucket, handle_bucket_kms), (Queue, handle_queue_kms)]
+            for target in mappings:
+                if isinstance(resource, target[0]) or issubclass(
+                    type(resource), target[0]
+                ):
+                    target[1](
+                        self,
+                        resource,
+                        resource.stack,
+                        settings,
+                    )
+
 
 class XStack(ComposeXStack):
     """
     Class for KMS Root stack
     """
 
-    def __init__(self, title, settings, **kwargs):
-        set_resources(settings, KmsKey, RES_KEY, MOD_KEY, mapping_key=MAPPINGS_KEY)
-        x_resources = settings.compose_content[RES_KEY].values()
-        new_resources = set_new_resources(x_resources, RES_KEY, True)
-        lookup_resources = set_lookup_resources(x_resources, RES_KEY)
-        use_resources = set_use_resources(x_resources, RES_KEY, False)
+    def __init__(
+        self, title, settings: ComposeXSettings, module: XResourceModule, **kwargs
+    ):
+        set_resources(settings, KmsKey, module)
+        x_resources = settings.compose_content[module.res_key].values()
+        lookup_resources = set_lookup_resources(x_resources)
+        new_resources = set_new_resources(x_resources, True)
         if new_resources:
             stack_template = build_template("Root template for KMS")
             super().__init__(title, stack_template, **kwargs)
             create_kms_template(stack_template, new_resources, self)
         else:
             self.is_void = True
-        if lookup_resources or use_resources:
-            if not keyisset(RES_KEY, settings.mappings):
-                settings.mappings[RES_KEY] = {}
+        if lookup_resources:
+            if not keyisset(module.mapping_key, settings.mappings):
+                settings.mappings[module.mapping_key] = {}
             for resource in lookup_resources:
                 resource.lookup_resource(
                     KMS_KEY_ARN_RE, get_key_config, Key.resource_type, "kms:key"
                 )
-        for resource in settings.compose_content[RES_KEY].values():
+                settings.mappings[module.mapping_key].update(
+                    {resource.logical_name: resource.mappings}
+                )
+        for resource in settings.compose_content[module.res_key].values():
             resource.stack = self
