@@ -1,6 +1,5 @@
-#   -*- coding: utf-8 -*-
 #  SPDX-License-Identifier: MPL-2.0
-#  Copyright 2020-2021 John Mille <john@compose-x.io>
+#  Copyright 2020-2022 John Mille <john@compose-x.io>
 
 
 """
@@ -28,7 +27,9 @@ from troposphere.logs import LogGroup, ResourcePolicy
 
 from ecs_composex.common import NONALPHANUM, add_outputs, add_parameters, setup_logging
 from ecs_composex.common.cfn_conditions import define_stack_name
-from ecs_composex.common.services_helpers import get_closest_valid_log_retention_period
+from ecs_composex.compose.compose_services.helpers import (
+    get_closest_valid_log_retention_period,
+)
 from ecs_composex.iam import define_iam_policy
 from ecs_composex.opensearch.opensearch_params import OS_DOMAIN_PORT, OS_DOMAIN_SG
 from ecs_composex.resources_import import import_record_properties
@@ -350,7 +351,6 @@ def validate_instance_types_config(domain, props, instance_type, config):
         for top_config, false_prop in unsupported.items():
             if keyisset(top_config, props) and hasattr(props[top_config], false_prop):
                 value = getattr(props[top_config], false_prop)
-                print(domain.name, top_config, false_prop, value)
                 if value is not False:
                     raise ValueError(
                         f"{domain.name} - Property {top_config}.{false_prop} is enabled, but is "
@@ -571,12 +571,11 @@ def create_new_domains(new_domains, stack):
             domain.add_new_output_attribute(
                 OS_DOMAIN_PORT,
                 (
-                    f"{domain.logical_name}{OS_DOMAIN_PORT.return_value}",
-                    OS_DOMAIN_PORT,
-                    Ref,
-                    None,
+                    f"{domain.logical_name}{OS_DOMAIN_PORT.title}",
+                    OS_DOMAIN_PORT.Default,
+                    OS_DOMAIN_PORT.Default,
+                    False,
                 ),
             )
             add_parameters(stack.stack_template, [OS_DOMAIN_PORT])
-        domain.generate_resource_envvars()
         add_outputs(stack.stack_template, domain.outputs)
