@@ -1,13 +1,12 @@
-#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
-# Copyright 2020-2021 John Mille <john@compose-x.io>
+# Copyright 2020-2022 John Mille <john@compose-x.io>
 
 """
 RDS DB template generator
 """
 
 from compose_x_common.compose_x_common import keyisset
-from troposphere import AWS_NO_VALUE, GetAtt, If, Ref, Sub, Tags
+from troposphere import AWS_NO_VALUE, GetAtt, If, NoValue, Ref, Sub, Tags
 from troposphere.ec2 import SecurityGroup
 from troposphere.rds import (
     DBCluster,
@@ -74,7 +73,8 @@ def init_database_template(db):
         rds_conditions.USE_DB_SNAPSHOT_CON_T, rds_conditions.USE_DB_SNAPSHOT_CON
     )
     template.add_condition(
-        rds_conditions.NOT_USE_DB_SNAPSHOT_CON_T, rds_conditions.NOT_USE_DB_SNAPSHOT_CON
+        rds_conditions.NOT_USE_DB_SNAPSHOT_CON_T,
+        rds_conditions.NOT_USE_DB_SNAPSHOT_CON,
     )
     template.add_condition(
         rds_conditions.USE_CLUSTER_CON_T, rds_conditions.USE_CLUSTER_CON
@@ -160,9 +160,15 @@ def add_default_instance_definition(db, for_cluster=False):
     """
     props = {
         "Engine": Ref(DB_ENGINE_NAME),
-        "EngineVersion": Ref(DB_ENGINE_VERSION),
+        "EngineVersion": If(
+            rds_conditions.USE_CLUSTER_CON_T,
+            NoValue,
+            Ref(DB_ENGINE_VERSION),
+        ),
         "StorageType": If(
-            rds_conditions.USE_CLUSTER_CON_T, Ref(AWS_NO_VALUE), Ref(DB_STORAGE_TYPE)
+            rds_conditions.USE_CLUSTER_CON_T,
+            Ref(AWS_NO_VALUE),
+            Ref(DB_STORAGE_TYPE),
         ),
         "DBSubnetGroupName": If(
             rds_conditions.NOT_USE_CLUSTER_CON_T,
@@ -183,7 +189,9 @@ def add_default_instance_definition(db, for_cluster=False):
             ),
         ),
         "DBClusterIdentifier": If(
-            rds_conditions.USE_CLUSTER_CON_T, Ref(db.cfn_resource), Ref(AWS_NO_VALUE)
+            rds_conditions.USE_CLUSTER_CON_T,
+            Ref(db.cfn_resource),
+            Ref(AWS_NO_VALUE),
         ),
         "MasterUserPassword": If(
             rds_conditions.USE_CLUSTER_CON_T,
@@ -288,7 +296,10 @@ def add_parameter_group(template, db):
     :type db: ecs_composex.common.compose_resources.Rds
     """
 
-    parameters_properties = ["DBClusterParameterGroupName", "DBParameterGroupName"]
+    parameters_properties = [
+        "DBClusterParameterGroupName",
+        "DBParameterGroupName",
+    ]
     if db.properties and not any(
         key in parameters_properties for key in db.properties.keys()
     ):
